;; Generated package description from mmm-mode.el  -*- no-byte-compile: t -*-
(define-package "mmm-mode" "0.5.11.0.20240222.42825" "Allow Multiple Major Modes in a buffer" '((emacs "25.1") (cl-lib "0.2")) :commit "b1f5c7dbdc405e6e10d9ddd99a43a6b2ad61b176" :authors '(("Michael Abraham Shulman" . "viritrilbia@gmail.com")) :maintainer '("Dmitry Gutov" . "dmitry@gutov.dev") :keywords '("convenience" "faces" "languages" "tools") :url "https://github.com/dgutov/mmm-mode")
